summaryrefslogtreecommitdiff
path: root/Master/setuptl
diff options
context:
space:
mode:
authorStaszek Wawrykiewicz <staw@gust.org.pl>2007-01-13 19:25:26 +0000
committerStaszek Wawrykiewicz <staw@gust.org.pl>2007-01-13 19:25:26 +0000
commit6e91ee46ebae73eb22974fbfbaa97a14482b2931 (patch)
tree211c87c18b2dc511236d493983695e9141822dd5 /Master/setuptl
parente69195d37fe89c718d2472b61bec8d9e1cc413f4 (diff)
tlpmgui 1.56
git-svn-id: svn://tug.org/texlive/trunk@3429 c570f23f-e606-0410-a88d-b1316a301751
Diffstat (limited to 'Master/setuptl')
-rw-r--r--Master/setuptl/Changelog5
-rw-r--r--Master/setuptl/TLPM/blng.pm2
-rw-r--r--Master/setuptl/TLPM/check.pm2
-rw-r--r--Master/setuptl/TLPM/cmdl.pm2
-rw-r--r--Master/setuptl/TLPM/common.pm22
-rw-r--r--Master/setuptl/TLPM/constants.pm15
-rw-r--r--Master/setuptl/TLPM/help.pm21
-rw-r--r--Master/setuptl/TLPM/incl.pm2
-rw-r--r--Master/setuptl/TLPM/info.pm2
-rw-r--r--Master/setuptl/TLPM/inst.pm2
-rw-r--r--Master/setuptl/TLPM/list.pm2
-rw-r--r--Master/setuptl/TLPM/pkg.pm13
-rw-r--r--Master/setuptl/TLPM/reg.pm2
-rw-r--r--Master/setuptl/TLPM/uninst.pm2
-rwxr-xr-xMaster/setuptl/tlpm-i386-linux.pl (renamed from Master/setuptl/tlpm.pl)7
-rw-r--r--Master/setuptl/tlpm.exebin447269 -> 448304 bytes
-rw-r--r--Master/setuptl/tlpm.readme17
-rwxr-xr-xMaster/setuptl/tlpmgui-i386-linux (renamed from Master/setuptl/tlpmgui)bin2748926 -> 2747156 bytes
-rw-r--r--Master/setuptl/tlpmgui.exebin1515567 -> 1515902 bytes
19 files changed, 92 insertions, 26 deletions
diff --git a/Master/setuptl/Changelog b/Master/setuptl/Changelog
index b58c59aeadb..d3f36e81589 100644
--- a/Master/setuptl/Changelog
+++ b/Master/setuptl/Changelog
@@ -1,5 +1,5 @@
## 2005-2007 Tomasz Luczak tlu@technodat.com.pl
-# $Id: Changelog 229 2007-01-11 23:11:39Z tlu $
+# $Id: Changelog 233 2007-01-13 17:18:24Z tlu $
# History:
# 2005.05.03 TLu r.0.1 start project
# 2005.08.04 TLu r.0.11 last version for TL2004
@@ -20,4 +20,5 @@
# 2007.01.08 TLu r.1.52 improve install under Win98, install dviout requires accept
# 2007.01.08 TLu r.1.53 improve install GS under Win98
# 2007.01.10 TLu r.1.54 improve install GS under Win98, TL2007
-# 2007.01.11 TLu r.1.55 clean temp file of GS (WinNT only), improve dviout config, added Darwin libraries for Tile
+# 2007.01.11 TLu r.1.55 clean temp dir (GS (WinNT only), improve dviout config, added Darwin libraries for Tile
+# 2007.01.13 TLu r.1.56 added name of platform to name of tlpmgui, use tlpm-name-of-platform.pl \ No newline at end of file
diff --git a/Master/setuptl/TLPM/blng.pm b/Master/setuptl/TLPM/blng.pm
index ed087b0f322..1071298ccf5 100644
--- a/Master/setuptl/TLPM/blng.pm
+++ b/Master/setuptl/TLPM/blng.pm
@@ -1,4 +1,4 @@
-# This file belongs to TLPM v2.17, TeX Live Package Manager
+# This file belongs to TLPM v2.19, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl
# blng [-pf] <name>
diff --git a/Master/setuptl/TLPM/check.pm b/Master/setuptl/TLPM/check.pm
index 74fc45d66b4..89390961f3f 100644
--- a/Master/setuptl/TLPM/check.pm
+++ b/Master/setuptl/TLPM/check.pm
@@ -1,4 +1,4 @@
-# This file belongs to TLPM v2.17, TeX Live Package Manager
+# This file belongs to TLPM v2.19, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl
# check [-pf]
diff --git a/Master/setuptl/TLPM/cmdl.pm b/Master/setuptl/TLPM/cmdl.pm
index 93bc67497e0..bb52becb9a8 100644
--- a/Master/setuptl/TLPM/cmdl.pm
+++ b/Master/setuptl/TLPM/cmdl.pm
@@ -1,4 +1,4 @@
-# This file belongs to TLPM v2.17, TeX Live Package Manager
+# This file belongs to TLPM v2.19, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl
# cmdline parsing
diff --git a/Master/setuptl/TLPM/common.pm b/Master/setuptl/TLPM/common.pm
index c3da31d5077..a9e9cfcfc2d 100644
--- a/Master/setuptl/TLPM/common.pm
+++ b/Master/setuptl/TLPM/common.pm
@@ -1,4 +1,4 @@
-# This file belongs to TLPM v2.17, TeX Live Package Manager
+# This file belongs to TLPM v2.19, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl
# common procedures;
@@ -95,6 +95,26 @@ sub sys
return $?;
}
+sub set
+{
+ my ($key, $val);
+ while($key = shift @_)
+ {
+ if($key =~ /=/)
+ {
+ ($key, $val) = split("=",$key);
+ }
+ else
+ {
+ $val = shift(@_);
+ }
+ unless($key eq '')
+ {
+ $ENV{$key} = $val;
+ }
+ }
+}
+
# messaging
$message_prefix = '% ';
diff --git a/Master/setuptl/TLPM/constants.pm b/Master/setuptl/TLPM/constants.pm
index e0ff1069127..b7a85c69a8f 100644
--- a/Master/setuptl/TLPM/constants.pm
+++ b/Master/setuptl/TLPM/constants.pm
@@ -1,4 +1,4 @@
-# This file belongs to TLPM v2.17, TeX Live Package Manager
+# This file belongs to TLPM v2.19, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl
# widely used constants
@@ -10,7 +10,9 @@ $false = 0;
$reg_file = qr/([^\/\\]+)\z/o;
$reg_dirsep = qr/[\/\\]/o; # not /(\/|\\)/
+
# TLPM was originally windowish and is tested mostly on windows so
+
unless(defined $tlpm_os){$tlpm_os = 'win32'} # if in distribution, always defined in BEGIN block
if($tlpm_os eq 'win32'){$win32 = $true}
@@ -34,6 +36,7 @@ $parent_dir = &rel2abs('..',$curr_dir);
# tlpm related constants
+$tlpm_version ||= "_devel";
$tlpm_prompt = "tlpm" . $tlpm_version . ">";
$tlpm_log = $chr_dirsep . "tlpm.log"; # log file
@@ -47,11 +50,15 @@ $tl_lists = $tl_texmf . $chr_dirsep . "lists";
$chr_dirsep . "texmf-dist" . $chr_dirsep . "tpm",
$chr_dirsep . "texmf-doc" . $chr_dirsep . "tpm");
-# paths to source TL directory (relative to mounting point / drive)
+# paths to source TL directory (relative to CD/DVD mounting point / drive)
@tl_roots = ('',
$chr_dirsep . "texlive",
- $chr_dirsep . "texlive2004");
+ $chr_dirsep . "texlive2004",
+ # $chr_dirsep . "texlive2005",
+ # $chr_dirsep . "texlive2006",
+ # $chr_dirsep . "texlive2007"
+ );
# ZIP archive
@@ -67,7 +74,7 @@ if($win32)
}
else
{
- $tl_unzip = sub {return "unzip"}; # assuming in system
+ $tl_unzip = sub {return "unzip"}; # assuming available in the system
$tl_xcopy = "cp";
$sys_redir = '>/dev/null';
}
diff --git a/Master/setuptl/TLPM/incl.pm b/Master/setuptl/TLPM/incl.pm
index fdf7601a7f3..371a760415d 100644
--- a/Master/setuptl/TLPM/incl.pm
+++ b/Master/setuptl/TLPM/incl.pm
@@ -1,4 +1,4 @@
-# This file belongs to TLPM v2.17, TeX Live Package Manager
+# This file belongs to TLPM v2.19, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl
# incl <pkg> [-pfer] <mask>
diff --git a/Master/setuptl/TLPM/info.pm b/Master/setuptl/TLPM/info.pm
index d9902491f31..6ae1a67e291 100644
--- a/Master/setuptl/TLPM/info.pm
+++ b/Master/setuptl/TLPM/info.pm
@@ -1,4 +1,4 @@
-# This file belongs to TLPM v2.17, TeX Live Package Manager
+# This file belongs to TLPM v2.19, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl
# info <pkg>
diff --git a/Master/setuptl/TLPM/inst.pm b/Master/setuptl/TLPM/inst.pm
index 9aabd3a4174..65b5614b61e 100644
--- a/Master/setuptl/TLPM/inst.pm
+++ b/Master/setuptl/TLPM/inst.pm
@@ -1,4 +1,4 @@
-# This file belongs to TLPM v2.17, TeX Live Package Manager
+# This file belongs to TLPM v2.19, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl
# inst <pkg> [-jrou]
diff --git a/Master/setuptl/TLPM/list.pm b/Master/setuptl/TLPM/list.pm
index 0721f47d7db..8d8981bc941 100644
--- a/Master/setuptl/TLPM/list.pm
+++ b/Master/setuptl/TLPM/list.pm
@@ -1,4 +1,4 @@
-# This file belongs to TLPM v2.17, TeX Live Package Manager
+# This file belongs to TLPM v2.19, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl
# list [-pfe] <mask>
diff --git a/Master/setuptl/TLPM/pkg.pm b/Master/setuptl/TLPM/pkg.pm
index 1a969f355e5..a02cc4e9b8b 100644
--- a/Master/setuptl/TLPM/pkg.pm
+++ b/Master/setuptl/TLPM/pkg.pm
@@ -1,4 +1,4 @@
-# This file belongs to TLPM v2.17, TeX Live Package Manager
+# This file belongs to TLPM v2.19, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl
# packages handling
@@ -154,7 +154,9 @@ sub set_source
unless($batch_mode) # the last chance is prompt
{
print STDOUT "TeX Live source drive: ";
- $tl_source = <STDIN>;chomp $tl_source;
+ $tl_source = <STDIN>;
+ chomp $tl_source;
+ &resolve_env($tl_source);
if(&is_tl_root($tl_source))
{
return(0);
@@ -170,7 +172,9 @@ sub set_source
unless($batch_mode)
{
print STDOUT "TeX Live source mounting point: ";
- $tl_source = <STDIN>;chomp $tl_source;
+ $tl_source = <STDIN>;
+ chomp $tl_source;
+ &resolve_env($tl_source);
if(&is_tl_root($tl_source))
{
return(0);
@@ -264,7 +268,7 @@ sub set_target
{
&set_target_();
}
- # we tried to test if the directory is writable, but even CD drive respond to be writable...
+ # I tried to test if the directory is writable, but even CD drive respond to be writable...
#unless(-w $tl_target)
#{
# &undef_target();
@@ -277,6 +281,7 @@ sub set_target
sub set_target_
{
&norm_path($tl_target);
+ &resolve_env($tl_target);
$tl_target = &rel2abs($tl_target,$curr_dir);
$tl_target_indeed = $true;
}
diff --git a/Master/setuptl/TLPM/reg.pm b/Master/setuptl/TLPM/reg.pm
index c9cd74b4066..09246a2e7dc 100644
--- a/Master/setuptl/TLPM/reg.pm
+++ b/Master/setuptl/TLPM/reg.pm
@@ -1,4 +1,4 @@
-# This file belongs to TLPM v2.17, TeX Live Package Manager
+# This file belongs to TLPM v2.19, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl
# regexp and mask related functions
diff --git a/Master/setuptl/TLPM/uninst.pm b/Master/setuptl/TLPM/uninst.pm
index 1f789e896fb..f04fc5092db 100644
--- a/Master/setuptl/TLPM/uninst.pm
+++ b/Master/setuptl/TLPM/uninst.pm
@@ -1,4 +1,4 @@
-# This file belongs to TLPM v2.17, TeX Live Package Manager
+# This file belongs to TLPM v2.19, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl
# uninst <pkg> [-rjF] [dir]
diff --git a/Master/setuptl/tlpm.exe b/Master/setuptl/tlpm.exe
index 350b64172bd..767117ad49f 100644
--- a/Master/setuptl/tlpm.exe
+++ b/Master/setuptl/tlpm.exe
Binary files differ
diff --git a/Master/setuptl/tlpm.readme b/Master/setuptl/tlpm.readme
index 69c9bca6b23..e620ad70030 100644
--- a/Master/setuptl/tlpm.readme
+++ b/Master/setuptl/tlpm.readme
@@ -105,6 +105,10 @@ Bugs reports and comments are welcome (tlpmgui@gust.org.pl)
there is no such a command available anymore; program version
is displayed in the banner and command prompt
09.01.2007, 2.17 -- code comments, readme changes
+12.01.2007, 2.18 -- since 'cmd set...' does not work as expected (the variable is
+ not kept in the environment during TLPM session), we introduce
+ new 'set' command
+12.01.2007, 2.19 -- protection from defining variables of empty name
* Known issues
1. Installation from DVD is much slower than from CD. Sorry...
@@ -145,6 +149,7 @@ uninst uninstall a package from specified target directory
check check installation dependencies and consistency
info show package info
help show this help or the given command description
+set set environment variable for current TLPM session
cmd execute a system command
quit leave the program
@@ -388,6 +393,18 @@ info context
+##################################### set #####################################
+USAGE:
+set <key-val list>
+
+DESCRIPTION:
+(Re)Sets environment variable for the current TLPM session.
+
+EXAMPLES:
+set TEXMFCNF=D:/TeX/texmf/web2c LOFO=.;lofo//
+
+
+
##################################### cmd #####################################
USAGE:
cmd <command>
diff --git a/Master/setuptl/tlpmgui b/Master/setuptl/tlpmgui-i386-linux
index 0ad89397fd6..7b19e4c6cf1 100755
--- a/Master/setuptl/tlpmgui
+++ b/Master/setuptl/tlpmgui-i386-linux
Binary files differ
diff --git a/Master/setuptl/tlpmgui.exe b/Master/setuptl/tlpmgui.exe
index 66115aca7a9..9a87f5d1b31 100644
--- a/Master/setuptl/tlpmgui.exe
+++ b/Master/setuptl/tlpmgui.exe
Binary files differ
diff --git a/Master/setuptl/TLPM/help.pm b/Master/setuptl/TLPM/help.pm
index b8dc62535a7..5a970d7c114 100644
--- a/Master/setuptl/TLPM/help.pm
+++ b/Master/setuptl/TLPM/help.pm
@@ -1,4 +1,4 @@
# This file belongs to TLPM v2.17, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl
# help
@@ -141,6 +141,10 @@ Bugs reports and comments are welcome (tlpmgui\@gust.org.pl)
there is no such a command available anymore; program version
is displayed in the banner and command prompt
09.01.2007, 2.17 -- code comments, readme changes
+12.01.2007, 2.18 -- since 'cmd set...' does not work as expected (the variable is
+ not kept in the environment during TLPM session), we introduce
+ new 'set' command
+12.01.2007, 2.19 -- protection from defining variables of empty name
* Known issues
1. Installation from DVD is much slower than from CD. Sorry...
@@ -176,6 +180,7 @@ uninst uninstall a package from specified target directory
check check installation dependencies and consistency
info show package info
help show this help or the given command description
+set set environment variable for current TLPM session
cmd execute a system command
quit leave the program
@@ -427,14 +432,24 @@ cmd mount /dev/cd /mnt/cd
cmd tex \\input story \\end
% clear screen
-cmd clear"
+cmd clear",
+
+'set' =>
+"USAGE:
+set \<key-val list\>
+
+DESCRIPTION:
+(Re)Sets environment variable for the current TLPM session.
+
+EXAMPLES:
+set TEXMFCNF=D:/TeX/texmf/web2c LOFO=.;lofo//"
);
sub readme
{
my $z;
my $sep = '#';
- my @topics = qw( technical_notes tlpm list incl blng inst uninst check help info cmd quit);
+ my @topics = qw( technical_notes tlpm list incl blng inst uninst check help info set cmd quit);
$heeelp -> (shift @topics);
$mess -> ("\n" . $sep x $row_length . "\n" . ' ' x 30 . "COMMANDS IN DETAILS\n" . $sep x $row_length );
foreach(@topics)
@@ -1,4 +1,4 @@
-# This file belongs to TLPM v2.17, TeX Live Package Manager
+# This file belongs to TLPM v2.19, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl
# help
diff --git a/Master/setuptl/tlpm.pl b/Master/setuptl/tlpm-i386-linux.pl
index f98f9070b65..c226e0eec54 100755
--- a/Master/setuptl/tlpm.pl
+++ b/Master/setuptl/tlpm-i386-linux.pl
@@ -1,8 +1,8 @@
#!/usr/bin/env perl
# This file belongs to TLPM v2.17, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl
-BEGIN{$tlpm_version="2.17";$tlpm_os="i386-linux"}
+BEGIN{$tlpm_version="2.19";$tlpm_os="i386-linux"}
# the main tlpm script
@@ -37,7 +37,8 @@ use TLPM::info;
# 'Help' => \&readme,
# 'readme' => \&readme,
# 'version' => \&version,
- 'cmd' => \&sys
+ 'cmd' => \&sys,
+ 'set' => \&set
);
# interactive mode
@@ -1,8 +1,8 @@
#!/usr/bin/env perl
-# This file belongs to TLPM v2.17, TeX Live Package Manager
+# This file belongs to TLPM v2.19, TeX Live Package Manager
# Public Domain, P.Jackowski@gust.org.pl